@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2020, 2021 Oracle and its affiliates.
+# Copyright (c) 2020, 2022 Oracle and/or its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 import copy
@@ -30,9 +30,7 @@ class Recommendation:
         "Fix imbalance in dataset",
     ]
 
-    @runtime_dependency(
-        module="ipywidgets.widgets", install_from="oracle-ads[notebook]"
-    )
+    @runtime_dependency(module="ipywidgets", install_from="oracle-ads[notebook]")
     def __init__(self, ds, recommendation_transformer):
         self.recommendation_transformer = recommendation_transformer
         self.reco_dict = recommendation_transformer.reco_dict_
@@ -42,7 +40,7 @@ class Recommendation:
         self.fill_nan_dict_values = {}
         self.fill_nan_dict = {}
         self.recommendation_type_index = 0
-        self.out = widgets.Output()
+        self.out = ipywidgets.widgets.Output()
 
     def _clear_output(self):
         self.boxes = []
@@ -72,18 +70,18 @@ class Recommendation:
 
     def _show_constant_fill_widget(self, column):
         if column in self.ds.numeric_columns:
-            text = widgets.FloatText(
+            text = ipywidgets.widgets.FloatText(
                 description=column,
                 disabled=False,
                 style={"description_width": "initial"},
-                layout=Layout(width="auto"),
+                layout=ipywidgets.Layout(width="auto"),
             )
         else:
-            text = widgets.Text(
+            text = ipywidgets.widgets.Text(
                 description=column,
                 disabled=False,
                 style={"description_width": "initial"},
-                layout=Layout(width="auto"),
+                layout=ipywidgets.Layout(width="auto"),
             )
         # copy previously entered value
         if column in self.fill_nan_dict:
@@ -92,7 +90,7 @@ class Recommendation:
         display(text)
         if self.control_buttons is not None:
             # self.control_buttons.close()
-            self.control_buttons = HBox(self.control_buttons.children)
+            self.control_buttons = ipywidgets.HBox(self.control_buttons.children)
             display(self.control_buttons)
 
     def _get_apply_on_click(self):
@@ -165,7 +163,7 @@ class Recommendation:
                 else:
                     with self.out:
                         display(
-                            HTML(
+                            ipywidgets.HTML(
                                 """
                     <font size=4>
                         {}
@@ -176,7 +174,7 @@ class Recommendation:
                                     ]
                                 )
                             ),
-                            layout=Layout(display="flex"),
+                            layout=ipywidgets.Layout(display="flex"),
                         )
                         self.action_list[
                             self.recommendation_types[self.recommendation_type_index]
@@ -185,13 +183,13 @@ class Recommendation:
                         self.message_list = []
                         self.extra_info_list = []
                         for column in recommendation.keys():
-                            messages = Label(
+                            messages = ipywidgets.Label(
                                 recommendation[column]["Message"],
-                                layout=Layout(
+                                layout=ipywidgets.Layout(
                                     flex="auto", justify_content="flex-start"
                                 ),
                             )
-                            actions = widgets.Dropdown(
+                            actions = ipywidgets.widgets.Dropdown(
                                 options=recommendation[column]["Action"],
                                 value=recommendation[column]["Selected Action"],
                                 width="auto",
@@ -200,18 +198,20 @@ class Recommendation:
                                 "Up-sample" in recommendation[column]["Action"]
                                 and importlib.util.find_spec("imblearn") is None
                             ):
-                                extra_info = HTML(
+                                extra_info = ipywidgets.HTML(
                                     """Up-sample requires imbalanced-learn python package. <br>
                                             To install run <code> pip install imbalanced-learn </code>.
                                         """,
-                                    layout=Layout(flex="auto", flex_flow="wrap"),
+                                    layout=ipywidgets.Layout(
+                                        flex="auto", flex_flow="wrap"
+                                    ),
                                 )
                                 self.extra_info_list.append(extra_info)
                             else:
                                 self.extra_info_list.append(
-                                    Label(
+                                    ipywidgets.Label(
                                         "",
-                                        layout=Layout(
+                                        layout=ipywidgets.Layout(
                                             flex="auto", justify_content="flex-start"
                                         ),
                                     )
@@ -226,12 +226,12 @@ class Recommendation:
                                 )
                             )
                             self.column_list.append(
-                                Label(
+                                ipywidgets.Label(
                                     column
                                     + "(type: {0})".format(
                                         self.ds.sampled_df[column].dtype
                                     ),
-                                    layout=Layout(flex="auto"),
+                                    layout=ipywidgets.Layout(flex="auto"),
                                     color="grey",
                                 )
                             )
@@ -242,20 +242,20 @@ class Recommendation:
                                 ]
                             ].append(actions)
                         display(
-                            HBox(
+                            ipywidgets.HBox(
                                 [
-                                    VBox(self.column_list),
-                                    VBox(self.message_list),
-                                    VBox(
+                                    ipywidgets.VBox(self.column_list),
+                                    ipywidgets.VBox(self.message_list),
+                                    ipywidgets.VBox(
                                         self.action_list[
                                             self.recommendation_types[
                                                 self.recommendation_type_index
                                             ]
                                         ]
                                     ),
-                                    VBox(self.extra_info_list),
+                                    ipywidgets.VBox(self.extra_info_list),
                                 ],
-                                layout=Layout(
+                                layout=ipywidgets.Layout(
                                     display="flex",
                                     flex_flow="row",
                                     border="solid 2px",
@@ -279,12 +279,16 @@ class Recommendation:
         for constant_text in self.fill_nan_dict.values():
             self._show_constant_fill_widget(constant_text.description)
         if self.recommendation_type_index < len(self.recommendation_types):
-            apply_button = widgets.Button(description="Next", button_style="primary")
+            apply_button = ipywidgets.widgets.Button(
+                description="Next", button_style="primary"
+            )
         else:
-            apply_button = widgets.Button(description="Apply", button_style="primary")
+            apply_button = ipywidgets.widgets.Button(
+                description="Apply", button_style="primary"
+            )
         apply_button.on_click(self._get_apply_on_click())
-        reset_button = widgets.Button(description="Reset All")
+        reset_button = ipywidgets.widgets.Button(description="Reset All")
         reset_button.on_click(self._get_reset_on_click())
-        self.control_buttons = HBox([apply_button, reset_button])
+        self.control_buttons = ipywidgets.HBox([apply_button, reset_button])
         with self.out:
             display(self.control_buttons)
