@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021, 2022 Oracle and its affiliates.
+# Copyright (c) 2021, 2022 Oracle and/or its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 from typing import Any, Optional, Union
 import oci.data_science.models as data_science_models
@@ -159,6 +159,9 @@ class ModelDeploymentProperties(
             except:
                 self.model_id = None
 
+        if self.model_id:
+            self._config_model_id()
+
         # Process additional kwargs
         # Convert all keys to lower case
         kwargs = {str(k).lower(): v for k, v in kwargs.items()}
@@ -377,6 +380,34 @@ class ModelDeploymentProperties(
         setattr(self, property_name, value)
         return self
 
+    def _config_model_id(self):
+        """Sets the model ID in the model configuration details using the value of self.model_id
+        This method should be called before preparing the payload for OCI API.
+        """
+        if (
+            self.model_deployment_configuration_details
+            and self.model_deployment_configuration_details.model_configuration_details
+        ):
+            self.model_deployment_configuration_details.model_configuration_details.model_id = (
+                self.model_id
+            )
+        else:
+            self.with_instance_configuration({})
+
+    def to_oci_model(self, oci_model):
+        """Convert properties into an OCI data model
+
+        Parameters
+        ----------
+        oci_model : class
+            The class of OCI data model, e.g., oci.data_science_models.CreateModelDeploymentDetails
+
+        """
+        if self.model_id:
+            self._config_model_id()
+
+        return super().to_oci_model(oci_model)
+
     def build(self) -> data_science_models.CreateModelDeploymentDetails:
         """Converts the deployment properties to OCI CreateModelDeploymentDetails object.
         Converts a model URI into a model OCID if user passed in a URI.
